cmoncrawl.processor.pipeline.extractor.DomainRecordExtractor
============================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. autoclass:: DomainRecordExtractor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~DomainRecordExtractor.__init__
      ~DomainRecordExtractor.extract
      ~DomainRecordExtractor.extract_soup
      ~DomainRecordExtractor.filter_raw
      ~DomainRecordExtractor.filter_soup
      ~DomainRecordExtractor.preprocess
   
   

   
   
   